pub fn parse_gnu_args(args: &[String], cwd: &Path) -> ParsedArgsExpand description
Parse GNU/Clang-style compile arguments into structured form.
args should be the arguments after the compiler executable.
Relative paths are resolved against cwd.
pub fn parse_gnu_args(args: &[String], cwd: &Path) -> ParsedArgsParse GNU/Clang-style compile arguments into structured form.
args should be the arguments after the compiler executable.
Relative paths are resolved against cwd.